MultiColorTimeSeries

Enum MultiColorTimeSeries 

pub enum MultiColorTimeSeries<'a, P: PassbandTrait, T: Float> {
    Mapping(MappedMultiColorTimeSeries<'a, P, T>),
    Flat(FlatMultiColorTimeSeries<'a, P, T>),
    MappingFlat {
        mapping: MappedMultiColorTimeSeries<'a, P, T>,
        flat: FlatMultiColorTimeSeries<'a, P, T>,
    },
}

Variants



Mapping(MappedMultiColorTimeSeries<'a, P, T>)



Flat(FlatMultiColorTimeSeries<'a, P, T>)



MappingFlat

Fields

mapping: MappedMultiColorTimeSeries<'a, P, T>
flat: FlatMultiColorTimeSeries<'a, P, T>

Implementations

Source

impl<'a, P, T> MultiColorTimeSeries<'a, P, T>
where P: PassbandTrait, T: Float,

pub fn total_lenu(&self) -> usize

pub fn total_lenf(&self) -> T

pub fn passband_count(&self) -> usize

pub fn from_map(map: impl Into<BTreeMap<P, TimeSeries<'a, T>>>) -> Self

pub fn from_flat( t: impl Into<DataSample<'a, T>>, m: impl Into<DataSample<'a, T>>, w: impl Into<DataSample<'a, T>>, passbands: impl Into<Vec<P>>, ) -> Self

pub fn mapping_mut(&mut self) -> &mut MappedMultiColorTimeSeries<'a, P, T>

pub fn mapping(&self) -> Option<&MappedMultiColorTimeSeries<'a, P, T>>

pub fn flat_mut(&mut self) -> &mut FlatMultiColorTimeSeries<'a, P, T>

pub fn flat(&self) -> Option<&FlatMultiColorTimeSeries<'a, P, T>>

pub fn passbands<'slf>( &'slf self, ) -> Either<Keys<'slf, P, TimeSeries<'a, T>>, Iter<'slf, P>>
where 'a: 'slf,

pub fn insert( &mut self, passband: P, ts: TimeSeries<'a, T>, ) -> Option<TimeSeries<'a, T>>

Inserts new pair of passband and time series into the multicolor time series.

It always converts MultiColorTimeSeries to MultiColorTimeSeries::Mapping variant. Also it replaces existing time series if passband is already present, and returns old time series.