pub struct MultiColorTimeSeries<'a, P: PassbandTrait + 'a, T: Float> { /* private fields */ }Expand description
The self-referencing struct.
Implementations
Sourceimpl<'a, P, T> MultiColorTimeSeries<'a, P, T>where
P: PassbandTrait,
T: Float,
impl<'a, P, T> MultiColorTimeSeries<'a, P, T>where
P: PassbandTrait,
T: Float,
pub fn total_lenu(&self) -> usize
pub fn total_lenf(&self) -> T
pub fn passband_count(&self) -> usize
Sourcepub fn from_map(map: impl Into<BTreeMap<P, TimeSeries<'a, T>>>) -> Self
pub fn from_map(map: impl Into<BTreeMap<P, TimeSeries<'a, T>>>) -> Self
Build from an owned BTreeMap. Clones K passband keys into passband_vec.
Sourcepub fn from_flat(
t: impl Into<DataSample<'a, T>>,
m: impl Into<DataSample<'a, T>>,
w: impl Into<DataSample<'a, T>>,
passband: impl AsRef<[P]>,
) -> Self
pub fn from_flat( t: impl Into<DataSample<'a, T>>, m: impl Into<DataSample<'a, T>>, w: impl Into<DataSample<'a, T>>, passband: impl AsRef<[P]>, ) -> Self
Build from flat arrays, deduplicating passbands automatically.
Sourcepub fn from_flat_with_passband_vec(
t: impl Into<DataSample<'a, T>>,
m: impl Into<DataSample<'a, T>>,
w: impl Into<DataSample<'a, T>>,
passband: impl AsRef<[P]>,
uniq_passbands: Vec<P>,
) -> Self
pub fn from_flat_with_passband_vec( t: impl Into<DataSample<'a, T>>, m: impl Into<DataSample<'a, T>>, w: impl Into<DataSample<'a, T>>, passband: impl AsRef<[P]>, uniq_passbands: Vec<P>, ) -> Self
Build from flat arrays with a pre-built sorted unique passband vec.
Each item in passband is matched into uniq_passbands by binary search
with no extra clones for the N-length array.
Sourcepub fn from_flat_borrowed(
t: impl Into<DataSample<'a, T>>,
m: impl Into<DataSample<'a, T>>,
w: impl Into<DataSample<'a, T>>,
passband: Vec<&'a P>,
uniq_passbands: &'a [P],
) -> Self
pub fn from_flat_borrowed( t: impl Into<DataSample<'a, T>>, m: impl Into<DataSample<'a, T>>, w: impl Into<DataSample<'a, T>>, passband: Vec<&'a P>, uniq_passbands: &'a [P], ) -> Self
Build from flat arrays with a fully borrowed passband slice — zero passband clones.
uniq_passbands— the K unique passbands, borrowed with'a.passband— per-observation references intouniq_passbands, also'a.
The caller must ensure uniq_passbands is sorted and every element of passband
is present in uniq_passbands (verified by binary search at construction time).
Sourcepub fn with_mapping_mut<R>(
&mut self,
f: impl FnOnce(&mut MappedMultiColorTimeSeries<'_, 'a, P, T>) -> R,
) -> R
pub fn with_mapping_mut<R>( &mut self, f: impl FnOnce(&mut MappedMultiColorTimeSeries<'_, 'a, P, T>) -> R, ) -> R
Run a closure with mutable access to the mapping representation.
Converts to MappingFlat or Mapping if currently Flat.
pub fn mapping(&self) -> Option<&MappedMultiColorTimeSeries<'_, 'a, P, T>>
pub fn with_flat_mut<R>( &mut self, f: impl FnOnce(&mut FlatMultiColorTimeSeries<'_, 'a, P, T>) -> R, ) -> R
pub fn flat(&self) -> Option<&FlatMultiColorTimeSeries<'_, 'a, P, T>>
pub fn passbands(&self) -> impl Iterator<Item = &P>
Sourcepub fn insert(
&mut self,
passband: P,
ts: TimeSeries<'a, T>,
) -> Option<TimeSeries<'a, T>>
pub fn insert( &mut self, passband: P, ts: TimeSeries<'a, T>, ) -> Option<TimeSeries<'a, T>>
Inserts a new passband / time-series pair, converting to mapping form.